@@ -1,7 +1,7 @@
 require 'mkmf'
 #have_library('stdc++', "main")
 #have_library('svm', "main")
-$CFLAGS = "-Wall -O3 "
+$CFLAGS = "#{ENV['CFLAGS']} -Wall -O3 "
 pkg_config 'libsvm'
 if CONFIG["MAJOR"].to_i >= 1 && CONFIG["MINOR"].to_i >= 8
   $CFLAGS << " -DHAVE_DEFINE_ALLOC_FUNCTION"
