@@ -612,6 +612,9 @@ void Init_SVM();
 
 void Init_SVM()
 {
+#ifdef QUIETFUNC
+  svm_set_verbosity(0);
+#endif
   mSVM = rb_define_module("SVM");
   cSVMProblem = rb_define_class_under(mSVM, "Problem", rb_cObject);
   cSVMParameter = rb_define_class_under(mSVM, "Parameter", rb_cObject);
